rt

package module
v0.0.0-...-3d597f3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MustNew

func MustNew(opts ...api.Options) api.Runtime

MustNew creates a new runtime with the given options, panicking on error.

func New

func New(opts ...api.Options) (api.Runtime, error)

New creates a new runtime with the given options.

Types

type OnErrorStrategy

type OnErrorStrategy = api.OnErrorStrategy
const (
	// OnErrorExit causes the process to exit if its internal function returns an error.
	OnErrorExit OnErrorStrategy = api.OnErrorExit

	// OnErrorRestart causes the process to be restarted if its internal function returns an error.
	OnErrorRestart OnErrorStrategy = api.OnErrorRestart
)

type Options

type Options = api.Options

type Proc

type Proc = api.Proc

type ProcessFn

type ProcessFn = api.ProcessFn

type ProcessHandle

type ProcessHandle = api.ProcessHandle

type ProcessState

type ProcessState = api.ProcessState

type PubSub

type PubSub = api.PubSub

type PubSubOptions

type PubSubOptions = api.PubSubOptions

Options reexports

type Runtime

type Runtime = api.Runtime

type SpawnOptions

type SpawnOptions = api.SpawnOptions

type SubscriptionHandle

type SubscriptionHandle = api.SubscriptionHandle

Directories

Path Synopsis
api

Jump to