Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type OnErrorStrategy ¶
type OnErrorStrategy = api.OnErrorStrategy
const ( // OnErrorExit causes the process to exit if its internal function returns an error. OnErrorExit OnErrorStrategy = api.OnErrorExit // OnErrorRestart causes the process to be restarted if its internal function returns an error. OnErrorRestart OnErrorStrategy = api.OnErrorRestart )
type ProcessHandle ¶
type ProcessHandle = api.ProcessHandle
type ProcessState ¶
type ProcessState = api.ProcessState
type SpawnOptions ¶
type SpawnOptions = api.SpawnOptions
type SubscriptionHandle ¶
type SubscriptionHandle = api.SubscriptionHandle
Click to show internal directories.
Click to hide internal directories.